Module imxrt_ral::src::SRSR

source ·
SRC Reset Status Register

Modules

Indicates whether the reset was the result of the csu_reset_b input.
Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)
Indicates whether the reset was the result of the ipp_user_reset_b qualified reset.
HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z reset from JTAG.
JTAG software reset
Indicates a reset has been caused by CPU lockup.
Temper Sensor software reset
IC Watchdog3 Time-out reset
IC Watchdog Time-out reset